@@ -148,7 +148,7 @@ class SerialCollectorPlugin(BaseCollectorPlugin):
 
         # for repo_url in self.context.manifest.get_repos():
         for repo_url in self._get_repos(comp):
-            logger.info(f"Looking in repository: {repo_url}")
+            logger.info(f"Repository: {repo_url}")
 
             repo_creds = Credentials.find_credentials(repo_url)
             result = self.collect(comp, repo_url, repo_creds)
