@@ -116,7 +116,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
             temp_repo = f"hoppr-tmp-{idx}"
             creds = Credentials.find_credentials(repo.url)
 
-            self.get_logger().info(f"Creating repo {temp_repo} for url {repo.url}")
+            self.get_logger().debug(f"Creating repo {temp_repo} for url {repo.url}")
 
             # Create temporary repository file
             repo_config[temp_repo] = {
@@ -153,7 +153,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         result = self.run_command(command, self.password_list)
 
         if result.returncode != 0:
-            return Result.fail("Failed to populate DNF cache.")
+            return Result.fail(message="Failed to populate DNF cache.")
 
         return Result.success()
 
@@ -166,7 +166,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         purl = PackageURL.from_string(comp.purl)
         artifact = _artifact_string(purl)
 
-        self.get_logger().info(f"Copying DNF package from {purl}")
+        self.get_logger().info(msg=f"Copying DNF package from {purl}", indent_level=2)
 
         # Try getting RPM URL
         command = [*self.base_command, "repoquery", "--location", artifact]
@@ -175,9 +175,9 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         # If RPM URL not found, no need to try downloading it
         if run_result.returncode != 0 or len(run_result.stdout.decode("utf-8")) == 0:
             msg = f"{self.required_commands[0]} failed to locate package for {purl}"
-            self.get_logger().debug(msg)
+            self.get_logger().debug(msg=msg, indent_level=2)
 
-            return Result.retry(msg)
+            return Result.retry(message=msg)
 
         # Taking the first URL if multiple are returned
         found_url = run_result.stdout.decode("utf-8").strip().split("\n")[0]
@@ -204,7 +204,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
 
         if run_result.returncode != 0:
             msg = f"Failed to download DNF artifact {purl.name} version {purl.version}"
-            return Result.retry(msg)
+            return Result.retry(message=msg)
 
         return Result.success()
 
