@@ -58,7 +58,18 @@ class CollectDockerPlugin(SerialCollectorPlugin):
         destination = "docker-archive:" + target_path
 
         self.get_logger().info(
-            f"Copying docker image from {source_url} to {destination}"
+            msg="Copying docker image:",
+            indent_level=2,
+        )
+
+        self.get_logger().info(
+            msg=f"source: {source_url}",
+            indent_level=3,
+        )
+
+        self.get_logger().info(
+            msg=f"destination: {destination}",
+            indent_level=3,
         )
 
         command = [self.required_commands[0], "copy"]
@@ -80,12 +91,16 @@ class CollectDockerPlugin(SerialCollectorPlugin):
                 f"Skopeo failed to copy docker image to {destination}, "
                 + f"return_code={proc.returncode}"
             )
-            self.get_logger().error(msg)
+
+            self.get_logger().debug(msg=msg, indent_level=2)
+
             if os.path.exists(target_path):
                 self.get_logger().info(
-                    "Artifact collection failed, deleting file and retrying"
+                    msg="Artifact collection failed, deleting file and retrying",
+                    indent_level=2,
                 )
                 os.remove(target_path)
-            return Result.retry(msg)
+
+            return Result.retry(message=msg)
 
         return Result.success()
