@@ -45,9 +45,13 @@ class CollectGitPlugin(SerialCollectorPlugin):
         if not git_result.is_success():
             return git_result
 
-        self.get_logger().info(f"Copying git repository from {repo_url}")
-
         source_url = os.path.join(repo_url, purl.namespace, purl.name)
+
+        self.get_logger().info(
+            msg=f"Cloning {source_url}",
+            indent_level=2,
+        )
+
         target_dir = self.directory_for(
             purl.type, repo_url, subdir=os.path.join(purl.namespace, purl.name)
         )
@@ -86,8 +90,8 @@ class CollectGitPlugin(SerialCollectorPlugin):
         )
         if result.returncode != 0:
             msg = f"Failed to clone {source_url}"
-            self.get_logger().error(msg)
-            return Result.retry(msg)
+            self.get_logger().debug(msg=msg, indent_level=2)
+            return Result.retry(message=msg)
 
         return Result.success()
 
@@ -106,7 +110,7 @@ class CollectGitPlugin(SerialCollectorPlugin):
         )
         if result.returncode != 0:
             msg = "Failed to make the clone usable as a remote"
-            self.get_logger().error(msg)
-            return Result.retry(msg)
+            self.get_logger().debug(msg=msg, indent_level=2)
+            return Result.retry(message=msg)
 
         return Result.success()
