@@ -56,9 +56,7 @@ class CollectPypiPlugin(SerialCollectorPlugin):
             purl.type, repo_url, subdir=f"{purl.name}_{purl.version}"
         )
 
-        self.get_logger().info(
-            f"Copying pypi artifact {purl.name}:{purl.version} from {repo_url} to {target_dir}"
-        )
+        self.get_logger().info(msg=f"Target directory: {target_dir}", indent_level=2)
 
         command = [
             self.required_commands[0],
@@ -79,8 +77,9 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         run_result = self.run_command(command, password_list)
         if run_result.returncode != 0:
-            self.get_logger().error(
-                f"Failed to download {purl.name} version {purl.version} binary"
+            self.get_logger().debug(
+                msg=f"Failed to download {purl.name} version {purl.version} binary",
+                indent_level=2,
             )
             got_binary = False
 
@@ -88,8 +87,9 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         run_result = self.run_command(command, password_list)
         if run_result.returncode != 0:
-            self.get_logger().error(
-                f"Failed to download {purl.name} version {purl.version} source"
+            self.get_logger().debug(
+                msg=f"Failed to download {purl.name} version {purl.version} source",
+                indent_level=2,
             )
             if not got_binary:
                 msg = (
