@@ -54,25 +54,52 @@ class CollectRawPlugin(SerialCollectorPlugin):
             source_file = Path(source_url.path, file_name).expanduser()
 
             self.get_logger().info(
-                f"Copying from {source_file} to {target_dir.joinpath(file_name)}"
+                msg="Copying component:",
+                indent_level=2,
             )
-            if not source_file.is_file():
-                msg = f"Unable to locate file {source_file}"
-                self.get_logger().info(msg)
-                return Result.fail(msg)
 
             self.get_logger().info(
-                f"Copying file from {source_file} to directory {target_dir}"
+                msg=f"source: {source_file}",
+                indent_level=3,
             )
+
+            self.get_logger().info(
+                msg=f"destination: {target_dir.joinpath(file_name)}",
+                indent_level=3,
+            )
+
+            if not source_file.is_file():
+                msg = (
+                    f"Unable to locate file {source_file}, skipping remaining attempts"
+                )
+                self.get_logger().error(msg=msg, indent_level=2)
+                return Result.fail(message=msg)
+
             shutil.copy(source_file, target_dir)
             return Result.success()
 
         download_url = urljoin(source_url.geturl() + "/", file_name)
 
         self.get_logger().info(
-            f"Downloading from {download_url} to file {target_dir.joinpath(file_name)}"
+            msg="Downloading file:",
+            indent_level=2,
+        )
+
+        self.get_logger().info(
+            msg=f"source: {download_url}",
+            indent_level=3,
+        )
+
+        self.get_logger().info(
+            msg=f"destination: {target_dir.joinpath(file_name)}",
+            indent_level=3,
         )
 
         response = download_file(download_url, target_dir.joinpath(file_name), creds)
+        result = Result.from_http_response(response)
 
-        return Result.from_http_response(response)
+        if result.is_fail():
+            msg = f"Unable to download from {download_url}, skipping remaining attempts"
+            self.get_logger().error(msg=msg, indent_level=2)
+
+        return result
