@@ -56,7 +56,9 @@ class CollectYumPlugin(SerialCollectorPlugin):
             return result
         artifact = _artifact_string(purl)
 
-        self.get_logger().info(f"Copying yum package from {comp.purl}")
+        self.get_logger().info(
+            msg=f"Copying yum package from {comp.purl}", indent_level=2
+        )
 
         command = [
             self.required_commands[0],
@@ -74,21 +76,25 @@ class CollectYumPlugin(SerialCollectorPlugin):
                 f"{self.required_commands[0]} failed to locate package for {comp.purl}, "
                 + f"return_code={run_result.returncode}"
             )
-            self.get_logger().error(msg)
+            self.get_logger().debug(msg=msg, indent_level=2)
 
-            return Result.retry(msg)
+            return Result.retry(message=msg)
 
         # Taking the first URL if multiple are returned
         found_url = run_result.stdout.decode("utf-8").strip().split("\n")[0]
 
         if not found_url.startswith(repo_url):
-            msg = (
-                "Yum download url does not match requested url.\n"
-                + f"   Yum download url:      {found_url}\n"
-                + f"   Expected url starting: {repo_url}"
+            msg = "Yum download url does not match requested url."
+
+            self.get_logger().error(msg=msg, indent_level=2)
+            self.get_logger().error(
+                msg=f"Yum download url:      {found_url}", indent_level=3
             )
-            self.get_logger().error(msg)
-            return Result.fail(msg)
+            self.get_logger().error(
+                msg=f"Expected url starting: {repo_url}", indent_level=3
+            )
+
+            return Result.fail(message=msg)
 
         found_url_path = Path(found_url)
         subdir = "/".join(found_url_path.parts[len(Path(repo_url).parts) : -1])
@@ -107,6 +113,6 @@ class CollectYumPlugin(SerialCollectorPlugin):
         run_result = self.run_command(command, [])
         if run_result.returncode != 0:
             msg = f"Failed to download Yum artifact {purl.name} version {purl.version} "
-            return Result.retry(msg)
+            return Result.retry(message=msg)
 
         return Result.success()
