@@ -13,9 +13,6 @@ class Plugin:
     Plugin Dataclass containing name and optional config
     """
 
-    name: str
-    config: Optional[dict]
-
     def __init__(self, name: str, config: Optional[dict] = None) -> None:
         self.name = name
         self.config = config
@@ -27,13 +24,11 @@ class Stage:
     Stage Dataclass containing an array of plugins
     """
 
-    name: str
-    plugins: list[Plugin]
-
-    def __init__(self, name: str, plugins: list[dict]) -> None:
-        self.name = name
-        self.plugins = []
-        for plugin in plugins:
+    def __init__(self, name: str, stage_config: dict) -> None:
+        self.name: str = name
+        self.component_coverage: Optional[str] = stage_config.get("component_coverage")
+        self.plugins: list[Plugin] = []
+        for plugin in stage_config.get("plugins", []):
             self.plugins.append(Plugin(**plugin))
 
 
@@ -42,11 +37,6 @@ class TransferFileContent:  # pylint: disable="too-few-public-methods"
     Transfer data type class to construct TransferType Object
     """
 
-    schema_version: str
-    kind: str
-    stages: list[Stage]
-    max_processes: int
-
     def __init__(
         self,
         schemaVersion: str,  # pylint: disable="invalid-name"
