@@ -4,6 +4,7 @@ Run Hoppr processing, using multiple processors
 from __future__ import annotations
 
 import os
+import logging
 import platform
 import shutil
 import socket
@@ -183,7 +184,7 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
         for plugin in self.plugins:
             if plugin.default_component_coverage != coverage:
                 raise HopprPluginError(
-                    f"Plugins for stage {self.stage_id} do not have consitent default "
+                    f"Plugins for stage {self.stage_id} do not have consistent default "
                     + "component coverage values.  The value may be overridden in transfer file."
                 )
 
@@ -264,13 +265,16 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
     Run the Hoppr process
     """
 
-    def __init__(self, transfer: Transfer, manifest: Manifest) -> None:
+    def __init__(
+        self, transfer: Transfer, manifest: Manifest, log_level: int = logging.INFO
+    ) -> None:
         self.transfer = transfer
         self.manifest = manifest
         self.context: Context
         self.stages: Dict = {}
         self.metadata_files: List[Path] = []
         self.logger: Optional[MemoryLogger] = None
+        self.log_level = log_level
 
     def get_logger(self):
         """
@@ -402,6 +406,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
                 collect_root_dir=collection_root,
                 consolidated_sbom=flatten_sboms(self.manifest),
                 max_processes=cpu_count(),
+                log_level=self.log_level,
             )
             if self.transfer.content:
                 self.context.max_processes = self.transfer.content.max_processes
@@ -418,6 +423,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
                 self.context.logfile_location,
                 lock=self.context.logfile_lock,
                 log_name=logger_name,
+                log_level=self.context.log_level,
                 flush_immed=True,
             )
 
@@ -432,9 +438,9 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
             if self.transfer.content is not None:
                 for stage_ref in self.transfer.content.stages:
                     self.get_logger().info(
-                        f"---------- Beginning Stage {stage_ref.name} ----------"
+                        f"{'=' * 10} Beginning Stage {stage_ref.name} {'=' * 50}"
                     )
-                    echo(f"---------- Beginning Stage {stage_ref.name} ----------")
+                    echo(f"{'=' * 10} Beginning Stage {stage_ref.name} {'=' * 50}")
 
                     stage = StageProcessor(stage_ref, self.context)
                     self.stages[stage_ref.name] = stage
